alter table store
    add daily_pay_store_association tinyint default 0 null comment '是否关联每日付门店 0:不关联 1:关联 默认 0';

alter table store
    add daily_pay_mch_id varchar(150) null comment '每日付门店商户编号';

alter table store
    add daily_pay_store_id varchar(150) null comment '每日付门店编号';

alter table store
    add daily_pay_store_name varchar(150) null comment '每日付门店名称';

create unique index idx_daily_pay_store_id
    on store (daily_pay_store_id)
    comment '每日付门店编号(ID)';




alter table card
    add term_card_type tinyint default 0 null comment '期限卡类型 0:普通会员卡 1:月付卡';

alter table card
    add term_card_reservation_limit_type tinyint null comment '期限卡每月可预约次数上限类型 0:自然月限制(每月的1号到月底(3月1号-3月31号))，1:开卡日期限制（开卡日期的当月到下月的开卡日期(3月15号-4月15号)）';

alter table card
    add term_card_reservation_limit int null comment '期限卡每月可约次数上限取值';

alter table card
    add daily_pay_product_id varchar(150) null comment '(月付卡)安心付商品ID';

alter table card
    add daily_pay_product_name varchar(200) null comment '(月付卡)安心付商品名称';

alter table card
    add daily_pay_product_price decimal(10, 2) null comment '(月付卡)安心付商品价格(元)';

alter table card
    add daily_pay_total_price decimal(10, 2) null comment '(月付卡)安心付商品总售价(元)';

alter table card
    add daily_pay_total_original_price decimal(10, 2) null comment '(月付卡)安心付商品总原价(元)';

alter table card
    add daily_pay_product_periods tinyint null comment '(月付卡)安心付商品分期数';

alter table card
    add daily_pay_product_buy_code_url text null comment '(月付卡)安心付商品购买码链接';

alter table card
    add daily_pay_product_cover text null comment '(期限卡)安心付商品封面';

alter table card
    add daily_pay_product_is_open_store tinyint null comment '(安心付)是否开放门店 0:否；1:是';

alter table card
    add daily_pay_product_open_store_count int null comment '(安心付)开放门店数量';



-- 表: 每日付关联会员卡关联门店信息
CREATE TABLE IF NOT EXISTS `daily_pay_card_store` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `card_uuid` bigint(20) NOT NULL COMMENT 'card.uuid',
  `store_uuid` bigint(20) NOT NULL COMMENT 'store.uuid',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_member_card_store` (`card_uuid`, `store_uuid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='每日付关联会员卡关联门店信息';

-- idx: store_uuid
CREATE INDEX `idx_store_uuid` ON `daily_pay_card_store` (`store_uuid`);




alter table store_card
    add daily_pay_card_status tinyint default 0 null comment '(月付卡)安心付会员卡上架状态 0: 下架 1: 上架 默认:0  card.term_card_type=1 此值才有效';


alter table store_card
    add term_card_reservation_limit_type tinyint null comment '(优先级高于card.term_card_reservation_limit_type)期限卡每月可预约次数上限类型 0:自然月限制(每月的1号到月底(3月1号-3月31号))，1:开卡日期限制（开卡日期的当月到下月的开卡日期(3月15号-4月15号)）';

alter table store_card
    add term_card_reservation_limit int null comment '(优先级高于card.term_card_reservation_limit)期限卡每月可约次数上限取值';


alter table user
    add monthly_pay_card_module_status tinyint default 0 null comment '用户是否已经进入了过月付卡模块 0:未进入月付卡模块 1:已经进入月付卡模块 默认:0';


CREATE TABLE `mini_program_dictionary`
(
    `uuid`        BIGINT    NOT NULL COMMENT '主键，雪花算法ID',
    `type`        TINYINT   NOT NULL DEFAULT 0 COMMENT '类型：0-月付费卡订购须知',
    `content`     TEXT      NOT NULL COMMENT '内容',
    `create_time` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`uuid`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4 COMMENT ='小程序字典数据表';

CREATE INDEX idx_type ON mini_program_dictionary(type);


alter table user_card
    modify reference_type tinyint(1) null comment '推荐人类型：1-员工；2-会员；3-陌生人; 4-无(月付卡)';


alter table card
    add daily_pay_product_no varchar(150) null comment '(月付卡)安心付商品编号' after daily_pay_product_id;

alter table user_card
    add daily_pay_order_id varchar(150) null comment '每日付订单ID:subscriptionNo';

alter table user_card
    add daily_pay_order_period int null comment '每日付期数';

create index idx_daily_pay_order_id
    on user_card (daily_pay_order_id);

CREATE TABLE IF NOT EXISTS `daily_pay_open_card_log` (
    `id` BIGINT NOT NULL COMMENT '雪花算法ID',
    `user_uuid` BIGINT NOT NULL COMMENT '用户ID',
    `card_uuid` BIGINT NOT NULL COMMENT '卡UUID',
    `user_card_uuid` BIGINT NOT NULL COMMENT '用户卡UUID',
    `daily_pay_order_no` VARCHAR(150) NOT NULL COMMENT '每日付订单号',
    `daily_pay_period` INT NOT NULL COMMENT '每日付期数',
    `daily_pay_product_id` VARCHAR(150) NOT NULL COMMENT '每日付商品ID',
    `daily_pay_product_no` VARCHAR(150) NOT NULL COMMENT '每日付商品编号',
    `daily_pay_product_name` VARCHAR(255) NOT NULL COMMENT '每日付商品名称',
    `open_card_result_info` TEXT COMMENT '开卡结果信息',
    `open_card_result_status` INT NOT NULL DEFAULT 0 COMMENT '开卡结果状态 0:失败 1:成功',
    `create_time` DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间 创建默认填充',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '每日付开卡日志';

-- 添加索引
-- user_uuid 索引
CREATE INDEX idx_user_uuid ON daily_pay_open_card_log (user_uuid);

-- user_card_uuid 索引
CREATE INDEX idx_user_card_uuid ON daily_pay_open_card_log (user_card_uuid);

-- daily_pay_order_no 索引
CREATE INDEX idx_daily_pay_order_no ON daily_pay_open_card_log (daily_pay_order_no);

alter table daily_pay_open_card_log
    add store_uuid BIGINT null comment '门店UUID' after id;

create index idx_store_uuid
    on daily_pay_open_card_log (store_uuid);


alter table user_card_change_logs
    add daily_pay_remark varchar(200) null comment '每日付备注信息';

alter table user_card_change_logs
    add daily_pay_current_total_price decimal(10, 2) null comment '每日付总售价';

alter table user_card_change_logs
    add daily_pay_periods int null comment '每日付总期数';

alter table user_card
    add daily_pay_remaining_periods int null comment '当前每日付订单剩余期数';

alter table user_card
    add term_card_reservation_limit_type tinyint null comment '期限卡每月可预约次数上限类型 0:自然月限制(每月的1号到月底(3月1号-3月31号))，1:开卡日期限制（开卡日期的当月到下月的开卡日期(3月15号-4月15号)）';

alter table user_card
    add term_card_reservation_limit int null comment '期限卡每月可约次数上限取值';

alter table daily_pay_open_card_log
    add open_card_action tinyint not null comment '开卡操作：0:开卡 1:续卡' after open_card_result_status;

alter table daily_pay_open_card_log
    modify daily_pay_product_no varchar(150) null comment '每日付商品编号';

alter table daily_pay_open_card_log
    modify daily_pay_product_name varchar(255) null comment '每日付商品名称';

alter table user_card_change_logs
    add leave_proofs text null comment '请假凭证, PNG Set<String> --> JSON String';

-- 表名称： daily_payment_task_log
CREATE TABLE IF NOT EXISTS `daily_pay_task_log` (
    `id` BIGINT PRIMARY KEY COMMENT '主键ID',
    -- 执行时间
    `execution_time` DATETIME NOT NULL COMMENT '执行时间',
    -- 执行结果 0: 成功, 1: 失败
    `result` TINYINT NOT NULL COMMENT '执行结果 0: 成功, 1: 失败',
    -- 定时任务查询订单开始时间
    `query_order_start_time` DATETIME NOT NULL COMMENT '定时任务查询订单开始时间',
    -- 定时任务查询订单结束时间
    `query_order_end_time` DATETIME NOT NULL COMMENT '定时任务查询订单结束时间',
    -- 定时任务查询订单数量
    `query_order_count` INT NOT NULL COMMENT '定时任务查询订单数量',
    -- 错误信息
    `error_message` TEXT COMMENT '错误信息',
    `created_at` DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间'
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '每日付-开卡定时任务日志';
-- 索引
CREATE INDEX idx_execution_time ON daily_pay_task_log (execution_time);


alter table user_card_change_logs
    add term_card_reservation_limit_type tinyint null comment '期限卡每月可预约次数上限类型 0:自然月限制(每月的1号到月底(3月1号-3月31号))，1:开卡日期限制（开卡日期的当月到下月的开卡日期(3月15号-4月15号)）';

alter table user_card_change_logs
    add term_card_reservation_limit int null comment '期限卡每月可约次数上限取值';

alter table daily_pay_open_card_log
    modify card_uuid bigint null comment '卡UUID';

alter table daily_pay_open_card_log
    modify user_card_uuid bigint null comment '用户卡UUID';

alter table daily_pay_open_card_log
    modify daily_pay_product_id varchar(150) null comment '每日付商品ID';

alter table user_card_change_logs
    add renewal_total_times int null comment '月付卡续卡后总次数';






